@@ -89,7 +89,7 @@ gnome_bonobo_module_info_get (void)
 		N_("Bonobo Support"),
 		NULL, NULL,
 		NULL, bonobo_post_args_parse,
-		NULL, NULL, NULL, NULL
+		NULL, NULL, NULL, NULL, NULL
 	};
 
 	if (module_info.requirements == NULL) {
@@ -143,11 +143,10 @@ gnome_bonobo_activation_module_info_get (void)
 		"bonobo-activation", NULL, N_("Bonobo activation Support"),
 		NULL, NULL,
 		bonobo_activation_pre_args_parse, bonobo_activation_post_args_parse,
-		bonobo_activation_popt_options
+		bonobo_activation_popt_options, NULL, NULL, NULL,
+		bonobo_activation_get_goption_group
 	};
 
-	module_info.expansion1 = (gpointer) bonobo_activation_get_goption_group ();
-
 	if (module_info.version == NULL) {
 		module_info.version = g_strdup_printf
 			("%d.%d.%d",
@@ -509,11 +508,28 @@ gnome_vfs_module_info_get (void)
 		NULL, gnome_vfs_post_args_parse,
 		NULL,
 		NULL,
+		NULL,
+		NULL,
 		NULL
 	};
 	return &module_info;
 }
 
+static GOptionGroup *
+libgnome_module_get_goption_group (void)
+{
+	GOptionGroup *option_group;
+
+	option_group = g_option_group_new ("gnome",
+					   N_("GNOME Library"),
+					   N_("Show GNOME options"),
+					   NULL, NULL);
+	g_option_group_set_translation_domain (option_group, GETTEXT_PACKAGE);
+	g_option_group_add_entries (option_group, gnomelib_goptions);
+
+	return option_group;
+}
+
 /**
 * libgnome_module_info_get:
 * 
@@ -530,19 +546,11 @@ libgnome_module_info_get (void)
 		NULL, NULL,
 		NULL, libgnome_post_args_parse,
 		gnomelib_options,
-		NULL, NULL, NULL, NULL
+		NULL, NULL, NULL,
+		libgnome_module_get_goption_group
 	};
 	int i = 0;
 	
-	GOptionGroup *option_group;
-	option_group = g_option_group_new ("gnome",
-					   N_("GNOME Library"),
-					   N_("Show GNOME options"),
-					   NULL, NULL);
-	g_option_group_set_translation_domain (option_group, GETTEXT_PACKAGE);
-	g_option_group_add_entries (option_group, gnomelib_goptions);
-	module_info.expansion1 = (gpointer) option_group;
-
 	if (module_info.requirements == NULL) {
 		static GnomeModuleRequirement req[4];
 
